# CMAT

Companion MAss from Ttv modeling: a fast to constrain upper mass of the hidden companion from TTV data.

[![DOI](https://zenodo.org/badge/777723832.svg)](https://zenodo.org/doi/10.5281/zenodo.13739646)
